Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(299)

Unified Diff: sdk/lib/io/http.dart

Issue 14055003: Remove HttpClientRequest.response, as it's identical to HttpClientRequest.done. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/http/lib/src/io_client.dart ('k') | sdk/lib/io/http_impl.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/io/http.dart
diff --git a/sdk/lib/io/http.dart b/sdk/lib/io/http.dart
index 9a54af20c27d0421de5a5aebcb119a3653b36218..97178dd2953dc719bb90fd0c9466b1c65f9eaea1 100644
--- a/sdk/lib/io/http.dart
+++ b/sdk/lib/io/http.dart
@@ -967,7 +967,7 @@ abstract class HttpClient {
* using one of the write methods taking a string.
*/
abstract class HttpClientRequest
- implements IOSink<HttpClientRequest> {
+ implements IOSink<HttpClientResponse> {
/**
* Gets and sets the content length of the request. If the size of
* the request is not known in advance set content length to -1,
@@ -996,10 +996,10 @@ abstract class HttpClientRequest
* available. If an error occurs before the response is available, this
* future will complete with an error.
*/
- Future<HttpClientResponse> get response;
+ Future<HttpClientResponse> get done;
/**
* Close the request for input. Returns the value of [response].
*/
Future<HttpClientResponse> close();
« no previous file with comments | « pkg/http/lib/src/io_client.dart ('k') | sdk/lib/io/http_impl.dart » ('j') | no next file with comments »
@@ -996,10 +996,10 @@ abstract class HttpClientRequest
/**
- * Close the request for input. Returns the value of [response].
+ * Close the request for input. Returns the value of [done].
*/
Future<HttpClientResponse> close();

Powered by Google App Engine
This is Rietveld 408576698